local pingFrame = CreateFrame("Frame", "LagMonitorFrame", UIParent);
local pingLocal = pingFrame:CreateFontString("PLocal", "OVERLAY");
local pingWorld = pingFrame:CreateFontString("PWorld", "OVERLAY");
local pLocal = pingFrame:CreateFontString("PLocal", "OVERLAY");
local pWorld = pingFrame:CreateFontString("PWorld", "OVERLAY");
local gFPS = pingFrame:CreateFontString("GFPS", "OVERLAY");
local gameFPS = pingFrame:CreateFontString("GFPS", "OVERLAY");
local LSM = LibStub("LibSharedMedia-3.0");
local updateInterval = 0;
local addonLoadedMessage = 'v1.5';
LagMonitor = LibStub("AceAddon-3.0"):NewAddon("LagMonitor", "AceConsole-3.0", "AceEvent-3.0")

--Global variable
userFont = "Font2";

local myFont = LSM:Fetch("font",userFont);

--Set frame moveable
pingFrame:SetMovable(true)
pingFrame:EnableMouse(true)
pingFrame:RegisterForDrag("LeftButton")
pingFrame:SetScript("OnDragStart", pingFrame.StartMoving)
pingFrame:SetScript("OnDragStop", pingFrame.StopMovingOrSizing)
pingFrame:SetPoint("TOP", UIParent, "CENTER", 0, 0)
pingFrame:SetSize(160, 60)

--Register addon loaded
pingFrame:RegisterEvent("ADDON_LOADED");
--Register player logout
pingFrame:RegisterEvent("PLAYER_LOGOUT");

--Slash commands
SLASH_PING1 = "/ping";
SLASH_PING2 = "/latency";
SLASH_PING3 = "/ms";

SlashCmdList["PING"] = function(self, txt)
	local up, down, home, world = GetNetStats();
	print("Home ping: " .. home);
	print("World ping: " .. world);
end

local options = {
    name = "LagMonitor " .. addonLoadedMessage,
    handler = LagMonitor,
    type = 'group',
    args = {
	
        showColText = {
            type = "toggle",
            name = "Set Colors",
			order = 1,
            desc = "Enable/disable colors stating quality of gameplay, for example: Green is Optimal, Orange/Yellow is Playable and Red is Poor",
            get = "IsShowColText",
            set = "ToggleShowColText",
        },
        closed = {
            type = "toggle",
            name = "Close",
			order = 2,
            desc = "Toggles the visibility of the addon",
            get = "IsClosed",
            set = "ToggleIsClosed"
        },
		reset = {
			type = "execute",
			name = "Reset",
			order = 3,
			desc = "Reset all the settings back to the default settings!",
			func = "ToggleIsReset"
		},
		changeFont = {
			type = "range",
			name = "Change Font Size",
			order = 4,
			min = 7,
			max = 17,
			get = "currentFontSize",
			set = "changeFontSize",
			step = 1
		},
    },
}

function LagMonitor:currentFontSize(info)
	return self.db.profile.fontSize
end

function LagMonitor:changeFontSize(info, value)
	self.db.profile.fontSize = value;
end

function LagMonitor:ToggleIsReset(info, value)
	self.db.profile.showColText = true;
	self.db.profile.closed = false;
	self.db.profile.fontSize = 17;
	pingFrame:Show();
	pingFrame:ClearAllPoints();
	pingFrame:SetPoint("CENTER");
end

function LagMonitor:IsShowColText(info)
    return self.db.profile.showColText
end

function LagMonitor:ToggleShowColText(info, value)
    self.db.profile.showColText = value
end

function LagMonitor:IsClosed(info)
    return self.db.profile.closed
end

function LagMonitor:ToggleIsClosed(info, value)
    self.db.profile.closed = value
	
	if value == true then
	pingFrame:Hide();
	end
	if value == false then
	pingFrame:Show();
	end
end

local defaults = {
    profile = {
        showColText = true,
        closed = false,
		fontSize = 17;
    },
}

function LagMonitor:OnInitialize()
    -- Called when the addon is loaded
	self:Print(addonLoadedMessage .. " Loaded!")
	self.db = LibStub("AceDB-3.0"):New("LagMonitorDB", defaults, true)
    LibStub("AceConfig-3.0"):RegisterOptionsTable("LagMonitor", options)
    self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("LagMonitor", "LagMonitor")
    self:RegisterChatCommand("lm", "ChatCommand")
    self:RegisterChatCommand("lagmonitor", "ChatCommand")
end

function LagMonitor:ChatCommand(input)
    if not input or input:trim() == "" then
        InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
    else
        LibStub("AceConfigCmd-3.0"):HandleCommand("lm", "LagMonitor", input)
    end
end

function pingFrame:OnEvent(event, arg1)
	if event == "ADDON_LOADED" and arg1 == "LagMonitor" then
	
		if LagMonitor.db.profile.closed == true then
			pingFrame:Hide();
		end
		if LagMonitor.db.profile.closed == false then
			pingFrame:Show();
		end
	
		--Declare font being used
	
		--Assign Local ping fonts
		pingLocal:SetFont(myFont,LagMonitor.db.profile.fontSize,"OUTLINE");
		pingLocal:SetPoint("RIGHT", pingFrame, "RIGHT", -2, 15);
	
		--Assign World ping fonts
		pingWorld:SetFont(myFont,LagMonitor.db.profile.fontSize,"OUTLINE");
		pingWorld:SetPoint("RIGHT", pingFrame, "RIGHT", -2, -1);
	
		
		--Assign Game fps fonts
		gameFPS:SetFont(myFont,LagMonitor.db.profile.fontSize,"OUTLINE");
		gameFPS:SetPoint("RIGHT", pingFrame, "RIGHT", -2, -17);
		
--PASTE BUTTON HERE
		
		--Assign Game fps fonts
		pLocal:SetFont(myFont,LagMonitor.db.profile.fontSize,"OUTLINE");
		pLocal:SetPoint("LEFT", pingFrame, "LEFT", 5, 15);
		
		--Assign Game fps fonts
		pWorld:SetFont(myFont,LagMonitor.db.profile.fontSize,"OUTLINE");
		pWorld:SetPoint("LEFT", pingFrame, "LEFT", 5, -1);
		
		--Assign Game fps fonts
		gFPS:SetFont(myFont,LagMonitor.db.profile.fontSize,"OUTLINE");
		gFPS:SetPoint("LEFT", pingFrame, "LEFT", 5, -17);
		
		pLocal:SetTextColor(1, 1, 0, 1);
		pLocal:SetFormattedText("Home(ms):");
		
		pWorld:SetTextColor(1, 1, 0, 1);
		pWorld:SetFormattedText("World(ms):");
		
		gFPS:SetTextColor(1, 1, 0, 1);
		gFPS:SetFormattedText("FPS:");
		
		local pingFrameBG = {
		bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background",  
  
		edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
  
		tile = true,
		--"Interface\\DialogFrame\\UI-DialogBox-Border"
  
		tileSize = 32,
		edgeSize = 20,
		insets = {
		left = 5,
		right = 5,
		top = 5,
		bottom = 5
			}
		}
		pingFrame:SetBackdrop(pingFrameBG);
	end
end

pingFrame:SetScript("OnEvent", pingFrame.OnEvent);

local function onUpdate(self, elapsed)

local up, down, home, world = GetNetStats();
local fps = GetFramerate();
--Change font sizes
pingLocal:SetFont(myFont,LagMonitor.db.profile.fontSize,"OUTLINE")
pingWorld:SetFont(myFont,LagMonitor.db.profile.fontSize,"OUTLINE")
gameFPS:SetFont(myFont,LagMonitor.db.profile.fontSize,"OUTLINE")
pLocal:SetFont(myFont,LagMonitor.db.profile.fontSize,"OUTLINE")
pWorld:SetFont(myFont,LagMonitor.db.profile.fontSize,"OUTLINE")
gFPS:SetFont(myFont,LagMonitor.db.profile.fontSize,"OUTLINE")

			if LagMonitor.db.profile.showColText == true then
				if home < 250 then
				pingLocal:SetTextColor(0, 1, 0, 1);
				end
				if ((home >= 250) and (home < 400)) then
				pingLocal:SetTextColor(1, 1, 0, 1);
				end
				if home >= 400 then
				pingLocal:SetTextColor(1, 0, 0, 1);
				end
			end
			if LagMonitor.db.profile.showColText == false then
				pingLocal:SetTextColor(1, 1, 0, 1);
			end
				if LagMonitor.db.profile.showColText == true then
				if world < 250 then
				pingWorld:SetTextColor(0, 1, 0, 1);
				end
				if ((world >= 250) and (world < 400)) then
				pingWorld:SetTextColor(1, 1, 0, 1);
				end
				if world >= 400 then
				pingWorld:SetTextColor(1, 0, 0, 1);
				end
			end
			if LagMonitor.db.profile.showColText == false then
				pingWorld:SetTextColor(1, 1, 0, 1);
			end
			


	updateInterval = updateInterval + elapsed
		if updateInterval >= 1 then	
		
			--Display Local ping
			pingLocal:SetFormattedText(home);
	
			--Display World ping
			pingWorld:SetFormattedText(world);
	
			--Display Game FPS
				if LagMonitor.db.profile.showColText == true then
				if floor(fps) <= 30 then
				gameFPS:SetTextColor(1, 0, 0, 1);
				end
				if ((floor(fps) > 30) and (floor(fps) <= 60)) then
				gameFPS:SetTextColor(1, 1, 0, 1);
				end
				if floor(fps) > 60 then
				gameFPS:SetTextColor(0, 1, 0, 1);
				end
			end
			if LagMonitor.db.profile.showColText == false then
				gameFPS:SetTextColor(1, 1, 0, 1);
			end
			gameFPS:SetFormattedText(floor(fps));
			
		updateInterval = 0;
		end
end

pingFrame:SetScript("OnUpdate", onUpdate);